#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-overloaded-record-dot-plugin
version:              2.3.0.0
visibility:           public
id:
    hls-overloaded-record-dot-plugin-2.3.0.0-D9dgJCwZRgG6aG4T3QrKQC

key:
    hls-overloaded-record-dot-plugin-2.3.0.0-D9dgJCwZRgG6aG4T3QrKQC

license:              BSD-3-Clause
maintainer:           joyfulmantis@gmail.com
author:               Nathan Maxson
synopsis:             Overloaded record dot plugin for Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  ff798ff93f2220a517e52c037dc6d4b9
exposed:              True
exposed-modules:      Ide.Plugin.OverloadedRecordDot
import-dirs:
    /usr/lib/ghc-9.6.6/site-local/hls-overloaded-record-dot-plugin-2.3.0.0

library-dirs:
    /usr/lib/ghc-9.6.6/site-local/hls-overloaded-record-dot-plugin-2.3.0.0

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/hls-overloaded-record-dot-plugin-2.3.0.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-overloaded-record-dot-plugin
hs-libraries:
    HShls-overloaded-record-dot-plugin-2.3.0.0-D9dgJCwZRgG6aG4T3QrKQC

depends:
    aeson-2.2.2.0-Bvq1RZLTB982HJyF7e96XU base-4.18.2.1 containers-0.6.7
    deepseq-1.4.8.1 ghc-boot-th-9.6.6
    ghcide-2.3.0.0-FPKe973dysnInOUVaCLUdu
    hls-graph-2.3.0.0-1gCW9OZ847s2g9dsPcBpND
    hls-plugin-api-2.3.0.0-D1GElmNt2iK2Wijr4TmkFu
    lens-5.3.4-4VhpdbpDp0x9CLN9dxQmc7
    lsp-2.2.0.0-BBA8C8ebAHoAYQmS8hf6TA syb-0.7.3-AsxB5kY1s6JBFiF2Kn9gZL
    text-2.0.2 transformers-0.6.1.0
    unordered-containers-0.2.20.1-ITIVaOGw28dDFkmcPJu0s3

haddock-interfaces:
    /usr/share/doc/haskell-hls-overloaded-record-dot-plugin/html/hls-overloaded-record-dot-plugin.haddock

haddock-html:
    /usr/share/doc/haskell-hls-overloaded-record-dot-plugin/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

